@@ -57,7 +57,7 @@ class DriftAnalysis:
         with open(path, "wb") as f:
             f.write(resp.content)
         
-        Logger.information(f"Saved PDF report!")
+        Logger.information("Saved PDF report!")
 
 
 
